@@ -45,7 +45,15 @@ class Common
         $GLOBALS['designer']['TABLE_NAME'] = array();// that foreach no error
         $GLOBALS['designer']['OWNER'] = array();
         $GLOBALS['designer']['TABLE_NAME_SMALL'] = array();
+        $GLOBALS['designer']['TABLE_TYPE'] = array();
 
+        $GLOBALS['designer_url']['TABLE_NAME'] = array();
+        $GLOBALS['designer_url']['OWNER'] = array();
+        $GLOBALS['designer_url']['TABLE_NAME_SMALL'] = array();
+
+        $GLOBALS['designer_out']['TABLE_NAME'] = array();
+        $GLOBALS['designer_out']['OWNER'] = array();
+        $GLOBALS['designer_out']['TABLE_NAME_SMALL'] = array();
         $tables = $GLOBALS['dbi']->getTablesFull($GLOBALS['db']);
         // seems to be needed later
         $GLOBALS['dbi']->selectDb($GLOBALS['db']);
@@ -80,7 +88,8 @@ class Common
 
             $DF = $this->relation->getDisplayField($GLOBALS['db'], $one_table['TABLE_NAME']);
             if ($DF != '') {
-                $retval[$GLOBALS['designer_url']["TABLE_NAME_SMALL"][$i]] = $DF;
+                $DF = rawurlencode((string)$DF);
+                $retval[rawurlencode($GLOBALS['designer_url']["TABLE_NAME_SMALL"][$i])] = $DF;
             }
 
             $i++;
@@ -144,12 +153,12 @@ class Common
             if ($row !== false) {
                 foreach ($row as $field => $value) {
                     $con['C_NAME'][$i] = '';
-                    $con['DTN'][$i]    = urlencode($GLOBALS['db'] . "." . $val[0]);
-                    $con['DCN'][$i]    = urlencode($field);
-                    $con['STN'][$i]    = urlencode(
+                    $con['DTN'][$i]    = rawurlencode($GLOBALS['db'] . "." . $val[0]);
+                    $con['DCN'][$i]    = rawurlencode($field);
+                    $con['STN'][$i]    = rawurlencode(
                         $value['foreign_db'] . "." . $value['foreign_table']
                     );
-                    $con['SCN'][$i]    = urlencode($value['foreign_field']);
+                    $con['SCN'][$i]    = rawurlencode($value['foreign_field']);
                     $i++;
                 }
             }
@@ -158,15 +167,15 @@ class Common
             if ($row !== false) {
                 foreach ($row['foreign_keys_data'] as $one_key) {
                     foreach ($one_key['index_list'] as $index => $one_field) {
-                        $con['C_NAME'][$i] = $one_key['constraint'];
-                        $con['DTN'][$i]    = urlencode($GLOBALS['db'] . "." . $val[0]);
-                        $con['DCN'][$i]    = urlencode($one_field);
-                        $con['STN'][$i]    = urlencode(
+                        $con['C_NAME'][$i] = rawurlencode($one_key['constraint']);
+                        $con['DTN'][$i]    = rawurlencode($GLOBALS['db'] . "." . $val[0]);
+                        $con['DCN'][$i]    = rawurlencode($one_field);
+                        $con['STN'][$i]    = rawurlencode(
                             (isset($one_key['ref_db_name']) ?
                                 $one_key['ref_db_name'] : $GLOBALS['db'])
                             . "." . $one_key['ref_table_name']
                         );
-                        $con['SCN'][$i] = urlencode($one_key['ref_index_list'][$index]);
+                        $con['SCN'][$i] = rawurlencode($one_key['ref_index_list'][$index]);
                         $i++;
                     }
                 }
@@ -180,8 +189,8 @@ class Common
             $dtn_i = $con['DTN'][$i];
             $retval[$ti] = array();
             $retval[$ti][$c_name_i] = array();
-            if (in_array($dtn_i, $GLOBALS['designer_url']["TABLE_NAME"])
-                && in_array($con['STN'][$i], $GLOBALS['designer_url']["TABLE_NAME"])
+            if (in_array(rawurldecode($dtn_i), $GLOBALS['designer_url']["TABLE_NAME"])
+                && in_array(rawurldecode($con['STN'][$i]), $GLOBALS['designer_url']["TABLE_NAME"])
             ) {
                 $retval[$ti][$c_name_i][$dtn_i] = array();
                 $retval[$ti][$c_name_i][$dtn_i][$con['DCN'][$i]] = array(
@@ -248,8 +257,8 @@ class Common
             if (Util::isForeignKeySupported($GLOBALS['designer']['TABLE_TYPE'][$i])) {
                 $j = 1;
             }
-            $retval['j_tabs'][$GLOBALS['designer_url']['TABLE_NAME'][$i]] = $j;
-            $retval['h_tabs'][$GLOBALS['designer_url']['TABLE_NAME'][$i]] = 1;
+            $retval['j_tabs'][\rawurlencode($GLOBALS['designer_url']['TABLE_NAME'][$i])] = $j;
+            $retval['h_tabs'][\rawurlencode($GLOBALS['designer_url']['TABLE_NAME'][$i])] = 1;
         }
         return $retval;
     }
@@ -265,7 +274,7 @@ class Common
     {
         $cfgRelation = $this->relation->getRelationsParam();
         if (! $cfgRelation['pdfwork']) {
-            return null;
+            return array();
         }
 
         $query = "
@@ -293,7 +302,7 @@ class Common
      *
      * @param int $pg pdf page id
      *
-     * @return string table name
+     * @return string|null table name
      */
     public function getPageName($pg)
     {
@@ -313,7 +322,7 @@ class Common
             DatabaseInterface::CONNECT_CONTROL,
             DatabaseInterface::QUERY_STORE
         );
-        return count($page_name) ? $page_name[0] : null;
+        return ( is_array($page_name) && isset($page_name[0]) ) ? $page_name[0] : null;
     }
 
     /**
@@ -361,7 +370,7 @@ class Common
     {
         $cfgRelation = $this->relation->getRelationsParam();
         if (! $cfgRelation['pdfwork']) {
-            return null;
+            return -1;
         }
 
         $query = "SELECT `page_nr`"
@@ -378,7 +387,7 @@ class Common
             DatabaseInterface::QUERY_STORE
         );
 
-        if (isset($default_page_no) && count($default_page_no)) {
+        if (is_array($default_page_no) && isset($default_page_no[0])) {
             return intval($default_page_no[0]);
         }
         return -1;
@@ -396,7 +405,7 @@ class Common
     {
         $cfgRelation = $this->relation->getRelationsParam();
         if (! $cfgRelation['pdfwork']) {
-            return null;
+            return -1;
         }
 
         $page_no = -1;
@@ -417,7 +426,7 @@ class Common
                 DatabaseInterface::CONNECT_CONTROL,
                 DatabaseInterface::QUERY_STORE
             );
-            if (isset($min_page_no[0]) && count($min_page_no[0])) {
+            if (is_array($min_page_no) && isset($min_page_no[0])) {
                 $page_no = $min_page_no[0];
             }
         }
