@@ -100,7 +100,7 @@ $operations = new Operations();
 /**
  * If the table has to be moved to some other database
  */
-if (isset($_REQUEST['submit_move']) || isset($_REQUEST['submit_copy'])) {
+if (isset($_POST['submit_move']) || isset($_POST['submit_copy'])) {
     //$_message = '';
     $operations->moveOrCopyTable($db, $table);
     // This was ended in an Ajax call
@@ -109,28 +109,28 @@ if (isset($_REQUEST['submit_move']) || isset($_REQUEST['submit_copy'])) {
 /**
  * If the table has to be maintained
  */
-if (isset($_REQUEST['table_maintenance'])) {
+if (isset($_POST['table_maintenance'])) {
     include_once 'sql.php';
     unset($result);
 }
 /**
  * Updates table comment, type and options if required
  */
-if (isset($_REQUEST['submitoptions'])) {
+if (isset($_POST['submitoptions'])) {
     $_message = '';
     $warning_messages = array();
 
-    if (isset($_REQUEST['new_name'])) {
+    if (isset($_POST['new_name'])) {
         // Get original names before rename operation
         $oldTable = $pma_table->getName();
         $oldDb = $pma_table->getDbName();
 
-        if ($pma_table->rename($_REQUEST['new_name'])) {
-            if (isset($_REQUEST['adjust_privileges'])
-                && ! empty($_REQUEST['adjust_privileges'])
+        if ($pma_table->rename($_POST['new_name'])) {
+            if (isset($_POST['adjust_privileges'])
+                && ! empty($_POST['adjust_privileges'])
             ) {
                 $operations->adjustPrivilegesRenameOrMoveTable(
-                    $oldDb, $oldTable, $_REQUEST['db'], $_REQUEST['new_name']
+                    $oldDb, $oldTable, $_POST['db'], $_POST['new_name']
                 );
             }
 
@@ -148,10 +148,10 @@ if (isset($_REQUEST['submitoptions'])) {
         }
     }
 
-    if (! empty($_REQUEST['new_tbl_storage_engine'])
-        && mb_strtoupper($_REQUEST['new_tbl_storage_engine']) !== $tbl_storage_engine
+    if (! empty($_POST['new_tbl_storage_engine'])
+        && mb_strtoupper($_POST['new_tbl_storage_engine']) !== $tbl_storage_engine
     ) {
-        $new_tbl_storage_engine = mb_strtoupper($_REQUEST['new_tbl_storage_engine']);
+        $new_tbl_storage_engine = mb_strtoupper($_POST['new_tbl_storage_engine']);
 
         if ($pma_table->isEngine('ARIA')) {
             $create_options['transactional'] = (isset($create_options['transactional']) && $create_options['transactional'] == '0')
@@ -190,28 +190,28 @@ if (isset($_REQUEST['submitoptions'])) {
         $warning_messages = $operations->getWarningMessagesArray();
     }
 
-    if (isset($_REQUEST['tbl_collation'])
-        && ! empty($_REQUEST['tbl_collation'])
-        && isset($_REQUEST['change_all_collations'])
-        && ! empty($_REQUEST['change_all_collations'])
+    if (isset($_POST['tbl_collation'])
+        && ! empty($_POST['tbl_collation'])
+        && isset($_POST['change_all_collations'])
+        && ! empty($_POST['change_all_collations'])
     ) {
         $operations->changeAllColumnsCollation(
-            $GLOBALS['db'], $GLOBALS['table'], $_REQUEST['tbl_collation']
+            $GLOBALS['db'], $GLOBALS['table'], $_POST['tbl_collation']
         );
     }
 }
 /**
  * Reordering the table has been requested by the user
  */
-if (isset($_REQUEST['submitorderby']) && ! empty($_REQUEST['order_field'])) {
+if (isset($_POST['submitorderby']) && ! empty($_POST['order_field'])) {
     list($sql_query, $result) = $operations->getQueryAndResultForReorderingTable();
 } // end if
 
 /**
  * A partition operation has been requested by the user
  */
-if (isset($_REQUEST['submit_partition'])
-    && ! empty($_REQUEST['partition_operation'])
+if (isset($_POST['submit_partition'])
+    && ! empty($_POST['partition_operation'])
 ) {
     list($sql_query, $result) = $operations->getQueryAndResultForPartition();
 } // end if
